@@ -7,10 +7,10 @@
 
 #include "publishdialog_p.h"
 
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
-#include <KEmailAddress>
+#include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <KCalendarCore/Person>
+#include <KEmailAddress>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -21,7 +21,8 @@
 using namespace KCalendarCore;
 using namespace Akonadi;
 
-PublishDialog::Private::Private(PublishDialog *qq) : QObject()
+PublishDialog::Private::Private(PublishDialog *qq)
+    : QObject()
     , q(qq)
 {
 }
@@ -78,7 +79,7 @@ void PublishDialog::Private::insertAddresses(const KContacts::Addressee::List &l
     for (const KContacts::Addressee &contact : list) {
         mUI.mNameLineEdit->setEnabled(true);
         mUI.mEmailLineEdit->setEnabled(true);
-        auto *item = new QListWidgetItem(mUI.mListWidget);
+        auto item = new QListWidgetItem(mUI.mListWidget);
         item->setSelected(true);
         mUI.mNameLineEdit->setText(contact.name());
         mUI.mEmailLineEdit->setText(contact.preferredEmail());
@@ -105,7 +106,7 @@ void PublishDialog::Private::openAddressbook()
             for (const Akonadi::EmailAddressSelection &selection : selections) {
                 mUI.mNameLineEdit->setEnabled(true);
                 mUI.mEmailLineEdit->setEnabled(true);
-                auto *item = new QListWidgetItem(mUI.mListWidget);
+                auto item = new QListWidgetItem(mUI.mListWidget);
                 item->setSelected(true);
                 mUI.mNameLineEdit->setText(selection.name());
                 mUI.mEmailLineEdit->setText(selection.email());
